@@ -47,6 +47,13 @@ def init_command(  # noqa: PLR0913
             help="Install the Griptape Nodes Advanced Image Library.",
         ),
     ] = None,
+    register_griptape_cloud_library: Annotated[
+        bool | None,
+        typer.Option(
+            "--register-griptape-cloud-library/--no-register-griptape-cloud-library",
+            help="Install the Griptape Cloud Library.",
+        ),
+    ] = None,
     libraries_sync: Annotated[
         bool | None,
         typer.Option("--libraries-sync/--no-libraries-sync", help="Sync the Griptape Nodes libraries."),
@@ -55,6 +62,10 @@ def init_command(  # noqa: PLR0913
         bool,
         typer.Option(help="Run init in non-interactive mode (no prompts)."),
     ] = False,
+    hf_token: Annotated[
+        str | None,
+        typer.Option(help="Set the Hugging Face token for downloading gated models."),
+    ] = None,
     config: Annotated[
         list[str] | None,
         typer.Option(
@@ -79,10 +90,12 @@ def init_command(  # noqa: PLR0913
             api_key=api_key,
             storage_backend=storage_backend,
             register_advanced_library=register_advanced_library,
+            register_griptape_cloud_library=register_griptape_cloud_library,
             config_values=config_values,
             secret_values=secret_values,
             libraries_sync=libraries_sync,
             bucket_name=bucket_name,
+            hf_token=hf_token,
         )
     )
 
@@ -128,7 +141,8 @@ def _run_init_configuration(config: InitConfig) -> None:
     _handle_workspace_config(config)
     _handle_storage_backend_config(config)
     _handle_bucket_config(config)
-    _handle_advanced_library_config(config)
+    _handle_hf_token_config(config)
+    _handle_additional_library_config(config)
     _handle_arbitrary_configs(config)
 
 
@@ -193,17 +207,43 @@ def _handle_bucket_config(config: InitConfig) -> str | None:
     return bucket_id
 
 
-def _handle_advanced_library_config(config: InitConfig) -> bool | None:
-    """Handle advanced library configuration step."""
+def _handle_hf_token_config(config: InitConfig) -> str | None:
+    """Handle Hugging Face token configuration step."""
+    hf_token = None
+
+    if config.interactive:
+        # First ask if they want to configure an HF token
+        configure_hf_token = _prompt_for_hf_token_configuration()
+        if configure_hf_token:
+            hf_token = _prompt_for_hf_token(default_hf_token=config.hf_token)
+    elif config.hf_token is not None:
+        hf_token = config.hf_token
+
+    if hf_token is not None:
+        secrets_manager.set_secret("HF_TOKEN", hf_token)
+        console.print("[bold green]Hugging Face token set[/bold green]")
+
+    return hf_token
+
+
+def _handle_additional_library_config(config: InitConfig) -> bool | None:
+    """Handle additional library configuration step."""
     register_advanced_library = config.register_advanced_library
+    register_griptape_cloud_library = config.register_griptape_cloud_library
 
     if config.interactive:
         register_advanced_library = _prompt_for_advanced_media_library(
             default_prompt_for_advanced_media_library=register_advanced_library
         )
+        register_griptape_cloud_library = _prompt_for_griptape_cloud_library(
+            default_prompt_for_griptape_cloud_library=register_griptape_cloud_library
+        )
 
-    if register_advanced_library is not None:
-        libraries_to_register = _build_libraries_list(register_advanced_library=register_advanced_library)
+    if register_advanced_library is not None or register_griptape_cloud_library is not None:
+        libraries_to_register = _build_libraries_list(
+            register_advanced_library=register_advanced_library,
+            register_griptape_cloud_library=register_griptape_cloud_library,
+        )
         config_manager.set_config_value(
             "app_events.on_app_initialization_complete.libraries_to_register", libraries_to_register
         )
@@ -445,8 +485,25 @@ def _prompt_for_advanced_media_library(*, default_prompt_for_advanced_media_libr
     return Confirm.ask("Register Advanced Media Library?", default=default_prompt_for_advanced_media_library)
 
 
-def _build_libraries_list(*, register_advanced_library: bool) -> list[str]:
-    """Builds the list of libraries to register based on the advanced library setting."""
+def _prompt_for_griptape_cloud_library(*, default_prompt_for_griptape_cloud_library: bool | None = None) -> bool:
+    """Prompts the user whether to register the Griptape Cloud Library."""
+    if default_prompt_for_griptape_cloud_library is None:
+        default_prompt_for_griptape_cloud_library = False
+    explainer = """[bold cyan]Griptape Cloud Library[/bold cyan]
+    Would you like to install the Griptape Nodes Griptape Cloud Library?
+    This node library makes Griptape Cloud APIs and functionality available within Griptape Nodes.
+    For example, nodes are available for invoking Structures, Assistants, or even publishing a Workflow to Griptape Cloud.
+    The Griptape Nodes Griptape Cloud Library can be added later by following instructions here: [bold blue][link=https://docs.griptapenodes.com]https://docs.griptapenodes.com[/link][/bold blue].
+    """
+    console.print(Panel(explainer, expand=False))
+
+    return Confirm.ask("Register Griptape Cloud Library?", default=default_prompt_for_griptape_cloud_library)
+
+
+def _build_libraries_list(
+    *, register_advanced_library: bool | None = False, register_griptape_cloud_library: bool | None = False
+) -> list[str]:
+    """Builds the list of libraries to register based on library settings."""
     # TODO: https://github.com/griptape-ai/griptape-nodes/issues/929
     libraries_key = "app_events.on_app_initialization_complete.libraries_to_register"
     library_base_dir = Path(ENV_LIBRARIES_BASE_DIR)
@@ -484,6 +541,20 @@ def _build_libraries_list(*, register_advanced_library: bool) -> list[str]:
         for lib in libraries_to_remove:
             new_libraries.remove(lib)
 
+    griptape_cloud_library = str(library_base_dir / "griptape_cloud/griptape_nodes_library.json")
+    griptape_cloud_identifier = _get_library_identifier(griptape_cloud_library)
+    if register_griptape_cloud_library:
+        # If the griptape cloud library is not registered, add it
+        if griptape_cloud_identifier not in current_identifiers:
+            new_libraries.append(griptape_cloud_library)
+    else:
+        # If the griptape cloud library is registered, remove it
+        libraries_to_remove = [
+            lib for lib in new_libraries if _get_library_identifier(lib) == griptape_cloud_identifier
+        ]
+        for lib in libraries_to_remove:
+            new_libraries.remove(lib)
+
     return new_libraries
 
 
@@ -513,6 +584,69 @@ def _create_new_bucket(bucket_name: str) -> str:
         return bucket_id
 
 
+def _prompt_for_hf_token_configuration() -> bool:
+    """Prompts the user whether to configure a Hugging Face token."""
+    # Check if there's already an HF token configured
+    current_hf_token = secrets_manager.get_secret("HF_TOKEN", should_error_on_not_found=False)
+
+    if current_hf_token:
+        explainer = """[bold cyan]Hugging Face Token Configuration[/bold cyan]
+    You currently have a Hugging Face token configured.
+
+    Hugging Face tokens are used to access gated models from the Hugging Face Hub, such as:
+    - Meta's Llama models
+    - black-forest-labs/FLUX.1-dev
+    - Other restricted or premium models
+
+    Would you like to update your Hugging Face token or keep the current one?"""
+        prompt_text = "Update Hugging Face token?"
+        default_value = False
+    else:
+        explainer = """[bold cyan]Hugging Face Token Configuration[/bold cyan]
+    Would you like to configure a Hugging Face token?
+
+    Hugging Face tokens are used by the model manager to download gated models from the Hugging Face Hub, such as:
+    - Meta's Llama models
+    - black-forest-labs/FLUX.1-dev
+    - Other restricted or premium models
+
+    If you don't plan to use gated models, you can skip this step.
+    You can get a token from https://huggingface.co/settings/tokens
+
+    You can always configure a token later by running the initialization process again."""
+        prompt_text = "Configure Hugging Face token?"
+        default_value = False
+
+    console.print(Panel(explainer, expand=False))
+    return Confirm.ask(prompt_text, default=default_value)
+
+
+def _prompt_for_hf_token(default_hf_token: str | None = None) -> str | None:
+    """Prompts the user for their Hugging Face token."""
+    if default_hf_token is None:
+        default_hf_token = secrets_manager.get_secret("HF_TOKEN", should_error_on_not_found=False)
+
+    explainer = """[bold cyan]Hugging Face Token[/bold cyan]
+    Please enter your Hugging Face token to enable downloading of gated models.
+
+    To get a token:
+    1. Go to https://huggingface.co/settings/tokens
+    2. Create a new token with 'Read' permissions
+    3. Copy and paste the token here
+
+    You can leave this blank to skip token configuration."""
+    console.print(Panel(explainer, expand=False))
+
+    hf_token = Prompt.ask(
+        "Hugging Face Token (optional)",
+        default=default_hf_token or "",
+        show_default=False,
+    )
+
+    # Return None if empty string
+    return hf_token if hf_token.strip() else None
+
+
 def _parse_key_value_pairs(pairs: list[str] | None) -> dict[str, Any] | None:
     """Parse key=value pairs from a list of strings.
 
