@@ -1,7 +1,8 @@
 from dataclasses import dataclass
-from typing import Literal
+from datetime import datetime
+from typing import TYPE_CHECKING, Literal
 
-from griptape_nodes.node_library.workflow_registry import WorkflowMetadata
+from griptape_nodes.node_library.workflow_registry import WorkflowMetadata, WorkflowShape
 from griptape_nodes.retained_mode.events.base_events import (
     RequestPayload,
     ResultPayloadFailure,
@@ -9,8 +10,12 @@ from griptape_nodes.retained_mode.events.base_events import (
     WorkflowAlteredMixin,
     WorkflowNotAlteredMixin,
 )
+from griptape_nodes.retained_mode.events.execution_events import ExecutionPayload
 from griptape_nodes.retained_mode.events.payload_registry import PayloadRegistry
 
+if TYPE_CHECKING:
+    from griptape_nodes.retained_mode.events.flow_events import SerializedFlowCommands
+
 
 @dataclass
 @PayloadRegistry.register
@@ -274,12 +279,14 @@ class SaveWorkflowRequest(RequestPayload):
     Args:
         file_name: Name of the file to save the workflow to (None for auto-generated)
         image_path: Path to save workflow image/thumbnail (None for no image)
+        pickle_control_flow_result: Whether to use pickle-based serialization for control flow results (None for default behavior)
 
     Results: SaveWorkflowResultSuccess (with file path) | SaveWorkflowResultFailure (save error)
     """
 
     file_name: str | None = None
     image_path: str | None = None
+    pickle_control_flow_result: bool | None = None
 
 
 @dataclass
@@ -382,8 +389,11 @@ class PublishWorkflowRequest(RequestPayload):
 
     workflow_name: str
     publisher_name: str
-    execute_on_publish: bool = False
+    # This can be removed after GUI release
+    execute_on_publish: bool | None = None
     published_workflow_file_name: str | None = None
+    pickle_control_flow_result: bool = False
+    metadata: dict | None = None
 
 
 @dataclass
@@ -396,6 +406,7 @@ class PublishWorkflowResultSuccess(ResultPayloadSuccess):
     """
 
     published_workflow_file_path: str
+    metadata: dict | None = None
 
 
 @dataclass
@@ -404,6 +415,20 @@ class PublishWorkflowResultFailure(ResultPayloadFailure):
     """Workflow publish failed. Common causes: workflow not found, publish error, file system error."""
 
 
+@dataclass
+@PayloadRegistry.register
+class PublishWorkflowProgressEvent(ExecutionPayload):
+    """Event emitted to indicate progress during workflow publishing.
+
+    Args:
+        progress: Progress percentage (0-100)
+        message: Optional progress message
+    """
+
+    progress: float
+    message: str | None = None
+
+
 @dataclass
 @PayloadRegistry.register
 class BranchWorkflowRequest(RequestPayload):
@@ -632,3 +657,56 @@ class RegisterWorkflowsFromConfigResultSuccess(WorkflowNotAlteredMixin, ResultPa
 @PayloadRegistry.register
 class RegisterWorkflowsFromConfigResultFailure(WorkflowNotAlteredMixin, ResultPayloadFailure):
     """Workflow registration from configuration failed. Common causes: configuration not found, invalid paths, registration errors."""
+
+
+@dataclass
+@PayloadRegistry.register
+class SaveWorkflowFileFromSerializedFlowRequest(RequestPayload):
+    """Save a workflow file from serialized flow commands without registry overhead.
+
+    Use when: Creating workflow files from user-supplied subsets of existing workflows,
+    exporting partial workflows, creating standalone workflow files without registration.
+
+    Args:
+        serialized_flow_commands: The serialized commands representing the workflow structure
+        file_name: Name for the workflow file (without .py extension)
+        creation_date: Optional creation date for the workflow metadata (defaults to current time if not provided)
+        image_path: Optional path to workflow image/thumbnail
+        execution_flow_name: Optional flow name to use for execution code (defaults to file_name if not provided)
+        branched_from: Optional branched from information to preserve workflow lineage
+        workflow_shape: Optional workflow shape defining inputs and outputs for external callers
+        file_path: Optional specific file path to use (defaults to workspace path if not provided)
+        pickle_control_flow_result: Whether to pickle control flow results in generated execution code (defaults to False)
+
+    Results: SaveWorkflowFileFromSerializedFlowResultSuccess (with file path) | SaveWorkflowFileFromSerializedFlowResultFailure (save error)
+    """
+
+    serialized_flow_commands: "SerializedFlowCommands"
+    file_name: str
+    file_path: str | None = None
+    creation_date: datetime | None = None
+    image_path: str | None = None
+    execution_flow_name: str | None = None
+    branched_from: str | None = None
+    workflow_shape: WorkflowShape | None = None
+    pickle_control_flow_result: bool = False
+
+
+@dataclass
+@PayloadRegistry.register
+class SaveWorkflowFileFromSerializedFlowResultSuccess(WorkflowNotAlteredMixin, ResultPayloadSuccess):
+    """Workflow file saved successfully from serialized flow commands.
+
+    Args:
+        file_path: Path where the workflow file was written
+        workflow_metadata: The metadata that was generated for the workflow
+    """
+
+    file_path: str
+    workflow_metadata: WorkflowMetadata
+
+
+@dataclass
+@PayloadRegistry.register
+class SaveWorkflowFileFromSerializedFlowResultFailure(WorkflowNotAlteredMixin, ResultPayloadFailure):
+    """Workflow file save failed. Common causes: file system error, permission denied, invalid serialized commands."""
